@@ -33,6 +33,7 @@ from reportlab.graphics.shapes import (
     _CLOSEPATH, Circle, Drawing, Ellipse, Group, Image, Line, Path, PolyLine,
     Polygon, Rect, SolidShape, String,
 )
+from reportlab.graphics.transform import mmult
 from reportlab.lib import colors
 from reportlab.lib.units import pica, toLength
 from reportlab.lib.utils import haveImages
@@ -63,10 +64,10 @@ def find_font(font_name, weight='normal', style='normal'):
     return _fonts_find_font(font_name, weight, style)
 
 
-__version__ = '1.1.0'
+__version__ = '1.2.1'
 __license__ = 'LGPL 3'
 __author__ = 'Dinu Gherman'
-__date__ = '2021-04-10'
+__date__ = '2022-01-27'
 
 XML_NS = 'http://www.w3.org/XML/1998/namespace'
 
@@ -368,7 +369,7 @@ class Svg2RlgAttributeConverter(AttributeConverter):
             if color is None:
                 # Test if text is a predefined color constant
                 try:
-                    color = getattr(colors, text)
+                    color = getattr(colors, text).clone()
                 except AttributeError:
                     pass
         if color is None:
@@ -481,7 +482,7 @@ class NodeTracker(ElementWrapper):
         self.usedAttrs = []
 
     def __repr__(self):
-        return '<NodeTracker for node %s>', self.object
+        return '<NodeTracker for node %s>' % self.object
 
     def getAttribute(self, name):
         # add argument to the history, if not already present
@@ -1030,7 +1031,7 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
         else:
             text = text.replace('\r\n', '').replace('\n', '').replace('\t', ' ')
             text = text.strip()
-            while ('  ' in text):
+            while '  ' in text:
                 text = text.replace('  ', ' ')
         return text
 
@@ -1333,8 +1334,8 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                 group.skew(values, 0)
             elif op == "skewY":
                 group.skew(0, values)
-            elif op == "matrix":
-                group.transform = values
+            elif op == "matrix" and len(values) == 6:
+                group.transform = mmult(group.transform, values)
             else:
                 logger.debug("Ignoring transform: %s %s", op, values)
 
@@ -1386,6 +1387,18 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                     if svgAttrValue == '':
                         if only_explicit:
                             continue
+                        if (
+                            svgAttrName == 'fill-opacity'
+                            and getattr(shape, 'fillColor', None) is not None
+                            and getattr(shape.fillColor, 'alpha', 1) != 1
+                        ):
+                            svgAttrValue = shape.fillColor.alpha
+                        elif (
+                            svgAttrName == 'stroke-opacity'
+                            and getattr(shape, 'strokeColor', None) is not None
+                            and getattr(shape.strokeColor, 'alpha', 1) != 1
+                        ):
+                            svgAttrValue = shape.strokeColor.alpha
                         else:
                             svgAttrValue = defaults[index]
                     if svgAttrValue == "currentColor":
